'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));

const loadElement = props => {
  const element = document.createElement(props.type);

  if (props.type === 'link') {
    element.href = props.src;
    element.type = `text/css`;
    element.rel = 'stylesheet';
  } else {
    element.src = props.src;
    element.type = `text/javascript`;
    element.async = true;
    element.defer = true;
  }

  if (props.onLoad) {
    element.addEventListener('load', props.onLoad);
  }

  document.head.appendChild(element);
};

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}
let firebaseUiDeletion = Promise.resolve();

class FirebaseAuth extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "unregisterAuthObserver", () => {});

    _defineProperty(this, "firebaseUiWidget", null);

    _defineProperty(this, "userSignedIn", null);

    _defineProperty(this, "handleLoad", () => {
      const _this$props = this.props,
            uiCallback = _this$props.uiCallback,
            uiConfig = _this$props.uiConfig,
            firebaseAuth = _this$props.firebaseAuth,
            id = _this$props.id;
      const _window = window,
            firebaseui = _window.firebaseui;
      return firebaseUiDeletion.then(() => {
        // Get or Create a firebaseUI instance.
        this.firebaseUiWidget = firebaseui.auth.AuthUI.getInstance() || new firebaseui.auth.AuthUI(firebaseAuth);

        if (uiConfig.signInFlow === 'popup') {
          this.firebaseUiWidget.reset();
        } // We track the auth state to reset firebaseUi if the user signs out.


        this.userSignedIn = false;
        this.unregisterAuthObserver = firebaseAuth.onAuthStateChanged(user => {
          if (!user && this.userSignedIn) {
            this.firebaseUiWidget.reset();
          }

          this.userSignedIn = !!user;
        }); // Trigger the callback if any was set.

        if (uiCallback) {
          uiCallback(this.firebaseUiWidget);
        } // Render the firebaseUi Widget.


        this.firebaseUiWidget.start(`#${id}`, uiConfig);
      });
    });

    _defineProperty(this, "loadTranslatedVersions", props => {
      const version = props.version,
            lng = props.lng;

      if (version && lng) {
        loadElement({
          src: `https://www.gstatic.com/firebasejs/ui/${version}/firebase-ui-auth__${lng}.js`,
          onLoad: this.handleLoad,
          type: 'script'
        });
        loadElement({
          src: `https://www.gstatic.com/firebasejs/ui/${version}/firebase-ui-auth.css`,
          type: 'link'
        });
      }
    });

    _defineProperty(this, "unmountWidget", () => {
      firebaseUiDeletion = firebaseUiDeletion.then(() => {
        this.unregisterAuthObserver();
        return this.firebaseUiWidget.delete();
      });
      return firebaseUiDeletion;
    });
  }

  componentDidMount() {
    this.loadTranslatedVersions(this.props);
  }

  componentDidUpdate(prevProps) {
    if (prevProps.lng !== this.props.lng || prevProps.version !== this.props.version) {
      this.unmountWidget();
      this.loadTranslatedVersions(this.props);
    }
  }

  componentWillUnmount() {
    this.unmountWidget();
  }

  render() {
    const _this$props2 = this.props,
          className = _this$props2.className,
          id = _this$props2.id;
    return React.createElement("div", {
      id: id,
      className: className
    });
  }

}

_defineProperty(FirebaseAuth, "displayName", 'FirebaseAuth');

_defineProperty(FirebaseAuth, "defaultProps", {
  id: 'firebaseui_container',
  version: '3.4.1',
  lng: 'es_419'
});

exports.FirebaseAuth = FirebaseAuth;
