function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { loadElement } from "../../utils/index.js";
let firebaseUiDeletion = Promise.resolve();

class FirebaseAuth extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "unregisterAuthObserver", () => {});

    _defineProperty(this, "firebaseUiWidget", null);

    _defineProperty(this, "userSignedIn", null);

    _defineProperty(this, "handleLoad", () => {
      const {
        uiCallback,
        uiConfig,
        firebaseAuth,
        id
      } = this.props;
      const {
        firebaseui
      } = window;
      return firebaseUiDeletion.then(() => {
        // Get or Create a firebaseUI instance.
        this.firebaseUiWidget = firebaseui.auth.AuthUI.getInstance() || new firebaseui.auth.AuthUI(firebaseAuth);

        if (uiConfig.signInFlow === 'popup') {
          this.firebaseUiWidget.reset();
        } // We track the auth state to reset firebaseUi if the user signs out.


        this.userSignedIn = false;
        this.unregisterAuthObserver = firebaseAuth.onAuthStateChanged(user => {
          if (!user && this.userSignedIn) {
            this.firebaseUiWidget.reset();
          }

          this.userSignedIn = !!user;
        }); // Trigger the callback if any was set.

        if (uiCallback) {
          uiCallback(this.firebaseUiWidget);
        } // Render the firebaseUi Widget.


        this.firebaseUiWidget.start(`#${id}`, uiConfig);
      });
    });

    _defineProperty(this, "loadTranslatedVersions", props => {
      const {
        version,
        lng
      } = props;

      if (version && lng) {
        loadElement({
          src: `https://www.gstatic.com/firebasejs/ui/${version}/firebase-ui-auth__${lng}.js`,
          onLoad: this.handleLoad,
          type: 'script'
        });
        loadElement({
          src: `https://www.gstatic.com/firebasejs/ui/${version}/firebase-ui-auth.css`,
          type: 'link'
        });
      }
    });

    _defineProperty(this, "unmountWidget", () => {
      firebaseUiDeletion = firebaseUiDeletion.then(() => {
        this.unregisterAuthObserver();
        return this.firebaseUiWidget.delete();
      });
      return firebaseUiDeletion;
    });
  }

  componentDidMount() {
    this.loadTranslatedVersions(this.props);
  }

  componentDidUpdate(prevProps) {
    if (prevProps.lng !== this.props.lng || prevProps.version !== this.props.version) {
      this.unmountWidget();
      this.loadTranslatedVersions(this.props);
    }
  }

  componentWillUnmount() {
    this.unmountWidget();
  }

  render() {
    const {
      className,
      id
    } = this.props;
    return React.createElement("div", {
      id: id,
      className: className
    });
  }

}

_defineProperty(FirebaseAuth, "displayName", 'FirebaseAuth');

_defineProperty(FirebaseAuth, "defaultProps", {
  id: 'firebaseui_container',
  version: '3.4.1',
  lng: 'es_419'
});

export default FirebaseAuth;